@@ -1,4 +1,4 @@
-DEFAULT = 'no_version'
+DEFAULT = '7.1.34'
 
 # Every loadmaster should have at least these capabilities
 BASE_CAPABILITIES = [
