@@ -21,7 +21,8 @@ from python_kemptech_api.exceptions import (
     ValidationError,
     SubVsCannotCreateSubVs,
     BackupFailed,
-    DownloadUserCertFailed)
+    DownloadUserCertFailed,
+    UnauthorizedAccessError)
 from python_kemptech_api.capabilities import CAPABILITIES, DEFAULT
 from .utils import (
     validate_port,
@@ -86,8 +87,13 @@ class HttpClient(object):
                                                      verify=False,
                                                      headers=headers,
                                                      cert=self.cert)
-            if 400 < response.status_code < 500:
-                raise KempTechApiException(msg=response.text)
+            if response.status_code == 401:
+                log.warning("Cannot authenticate, to %s check that the "
+                            "credentials are correct.", self.ip_address)
+                raise UnauthorizedAccessError(self.ip_address)
+            elif 400 < response.status_code < 500:
+                raise KempTechApiException(msg=response.text,
+                                           code=response.status_code)
             else:
                 response.raise_for_status()
         except exceptions.ConnectTimeout:
@@ -441,12 +447,10 @@ class LoadMaster(HttpClient):
                               parameters=params)
         return send_response(response)
 
-    def backup(self):
-        # Dirty API, dirty hack.
-
-        if not os.path.exists('backups'):
-            os.makedirs('backups')
-        file_name = "backups/{}.backup".format(self.ip_address)
+    def backup(self, location='backups'):
+        if not os.path.exists(location):
+            os.makedirs(location)
+        file_name = os.path.join(location, "{}.backup".format(self.ip_address))
 
         with open(file_name, 'wb') as file:
             cmd = self._get_curl_command_list('backup')
@@ -520,8 +524,8 @@ class LoadMaster(HttpClient):
         response = self._get('/usernewcert', params)
         return send_response(response)
 
-    def download_user_cert(self, user):
-        file_name = "{}.cert".format(user)
+    def download_user_cert(self, user, location=os.curdir):
+        file_name = os.path.join(location, "{}.cert".format(user))
 
         with open(file_name, 'wb') as file:
             cmd = self._get_curl_command_list('userdownloadcert?user={}'
