@@ -32,60 +32,69 @@ class KempTechApiException(Exception):
     """Raised if HTTP request has failed."""
 
     def __init__(self, msg=None, code=None, is_xml_msg=True):
+        self.status_code = code
         message = get_api_exception_message(msg, code, is_xml_msg)
         super(KempTechApiException, self).__init__(message)
 
 
 class KempConnectionError(KempTechApiException):
-    def __init__(self, endpoint):
+    def __init__(self, endpoint, code=None):
         msg = "A connection error occurred to {endpoint}."\
             .format(endpoint=endpoint)
-        super(KempConnectionError, self).__init__(msg)
+        super(KempConnectionError, self).__init__(msg, code=code)
+
+
+class UnauthorizedAccessError(KempTechApiException):
+    def __init__(self, cmd_url, code=None):
+        msg = "You do not have authorized access to {}. " \
+              "Please check your credentials.".format(cmd_url)
+        super(UnauthorizedAccessError, self).__init__(msg, code=code)
 
 
 class UrlRequiredError(KempTechApiException):
-    def __init__(self, cmd_url):
+    def __init__(self, cmd_url, code=None):
         msg = "{} is an invalid URL".format(cmd_url)
-        super(UrlRequiredError, self).__init__(msg)
+        super(UrlRequiredError, self).__init__(msg, code=code)
 
 
 class TooManyRedirectsException(KempTechApiException):
-    def __init__(self, cmd_url):
+    def __init__(self, cmd_url, code=None):
         msg = "Too many redirects with request to {}.".format(cmd_url)
-        super(TooManyRedirectsException, self).__init__(msg)
+        super(TooManyRedirectsException, self).__init__(msg, code=code)
 
 
 class TimeoutException(KempTechApiException):
-    def __init__(self, endpoint):
+    def __init__(self, endpoint, code=None):
         msg = "A connection {} has timed out.".format(endpoint)
-        super(TimeoutException, self).__init__(msg)
+        super(TimeoutException, self).__init__(msg, code=code)
 
 
 class HTTPError(KempTechApiException):
-    def __init__(self, cmd_url):
+    def __init__(self, cmd_url, code=None):
         msg = "A HTTP error occurred with request to {}.".format(cmd_url)
-        super(HTTPError, self).__init__(msg)
+        super(HTTPError, self).__init__(msg, code=code)
 
 
 class ApiNotEnabledError(KempTechApiException):
-    def __init__(self):
+    def __init__(self, code=None):
         msg = "Ensure the API is enabled on the LoadMaster."
-        super(ApiNotEnabledError, self).__init__(msg)
+        super(ApiNotEnabledError, self).__init__(msg, code=code)
 
 
 class CommandNotAvailableException(KempTechApiException):
-    def __init__(self, lm, cmd_name):
+    def __init__(self, lm, cmd_name, code=None):
         msg = "Command '{}' is not available on LoadMaster {}.".format(
             cmd_name, lm)
         super(CommandNotAvailableException, self).__init__(msg,
-                                                           is_xml_msg=False)
+                                                           is_xml_msg=False,
+                                                           code=code)
 
 
 class ConnectionTimeoutException(KempTechApiException):
-    def __init__(self, lm):
+    def __init__(self, lm, code=None):
         msg = "Connection timed out to '{}'.".format(lm)
         super(ConnectionTimeoutException, self).__init__(
-            msg, is_xml_msg=False)
+            msg, is_xml_msg=False, code=code)
 
 
 def get_parameter_message(obj, parameters):
@@ -153,15 +162,15 @@ class RealServerMissingVirtualServiceInfo(MissingInfo):
     param_name = 'Virtual service'
 
 
-class BackupFailed(Exception):
-    def __init__(self, ip_address):
+class BackupFailed(KempTechApiException):
+    def __init__(self, ip_address, code=None):
         msg = ("Failed to create a backup. Could not reach LoadMaster {}."
                .format(ip_address))
-        super(BackupFailed, self).__init__(msg)
+        super(BackupFailed, self).__init__(msg, code=code)
 
 
-class DownloadUserCertFailed(Exception):
-    def __init__(self, ip_address):
+class DownloadUserCertFailed(KempTechApiException):
+    def __init__(self, ip_address, code=None):
         msg = ("Failed to download user cert. Could not reach LoadMaster {}."
                .format(ip_address))
-        super(DownloadUserCertFailed, self).__init__(msg)
+        super(DownloadUserCertFailed, self).__init__(msg, code=code)
